@@ -3,9 +3,12 @@
     isort:skip_file
 """
 
-__version__ = '0.1.28'
-
+from truss.build import from_directory
+from pathlib import Path
+from single_source import get_version
 import logging
+
+
 from collections import defaultdict
 
 from baseten import baseten_artifact
@@ -14,7 +17,13 @@ from baseten.common.model_deployer import build_truss, deploy_truss, build_and_d
 from baseten.common.util import setup_logger  # noqa: E402
 from baseten.common import settings  # noqa: E402
 
-from truss.build import from_directory
+
+__version__ = get_version(__name__, Path(__file__).parent.parent)
+
+
+def version():
+    return __version__
+
 
 patched_modules = defaultdict(lambda: [])
 
