@@ -5,7 +5,7 @@ import os
 import tarfile
 import tempfile
 import time
-from typing import Dict, List
+from typing import Dict, List, Union
 
 import requests
 import yaml
@@ -57,6 +57,7 @@ def requirements_status(requirement_id: str):
 
 class BasetenDeployedModel:
     """A model backed by baseten serving. Provide either the model_id or the model_version_id."""
+
     def __init__(self, model_id: str = None,
                  model_version_id: str = None,
                  model_name: str = None,
@@ -80,13 +81,15 @@ class BasetenDeployedModel:
     @raises_api_error
     def predict(self,
                 inputs,
-                metadata=None) -> List[List]:
+                metadata=None,
+                prediction_only: bool = True) -> Union[List[List], Dict]:
         """Invokes the model given the input dataframe.
 
         Args:
             inputs: The data representing one or more inputs to call the model with.
                 Accepted types are: list, pandas.DataFrame, and numpy.ndarray
             metadata (Union[pd.DataFrame, List[Dict]]): Metadata key/value pairs (e.g. name, url), one for each input.
+            prediction_only (bool): set to `False` for the full response (including probablities).
 
         Returns:
             A list of inferences for each given input; e.g.: [[3], [9]] would indicate the prediction for the
@@ -100,8 +103,8 @@ class BasetenDeployedModel:
         inputs_list, metadata = coerce_input_to_json(inputs, metadata)
 
         if self._model_version_id:
-            return api.predict_for_model_version(self._model_version_id, inputs_list, metadata)
-        return api.predict_for_model(self._model_id, inputs_list, metadata)
+            return api.predict_for_model_version(self._model_version_id, inputs_list, metadata, prediction_only)
+        return api.predict_for_model(self._model_id, inputs_list, metadata, prediction_only)
 
     @raises_api_error
     def update_model_features(self, model_config_file_path: str):
