@@ -7,6 +7,7 @@ import sys
 import click
 from truss.cli import cli_group as truss_commands
 
+from baseten import version as b10_version
 from baseten.client_commands import baseten_cli, models_cli, pretrained_cli
 from baseten.common.settings import (read_config, set_config_value,
                                      set_server_url)
@@ -29,9 +30,23 @@ def ensure_login(func):
     return wrapper
 
 
-@click.group()
-def cli_group():
+@click.group(name="baseten", invoke_without_command=True)
+@click.pass_context
+@click.option(
+    "-v",
+    "--version",
+    is_flag=True,
+    show_default=False,
+    default=False,
+    help="Show baseten package version.",
+)
+def cli_group(ctx, version):
     setup_logger('baseten', logging.INFO)
+    if not ctx.invoked_subcommand:
+        if version:
+            click.echo(b10_version())
+        else:
+            click.echo(ctx.get_help())
 
 
 @cli_group.command()
