@@ -5,7 +5,7 @@ import logging
 import os
 import tarfile
 import tempfile
-from typing import IO, Dict, List
+from typing import IO, Dict, List, Union
 
 import requests
 from colorama import Fore, Style
@@ -566,7 +566,11 @@ def model_version_linked_artifacts(
 
 
 @with_api_key
-def predict_for_model(api_key, model_id: str, inputs: list, metadata: List[Dict] = None) -> List[List]:
+def predict_for_model(api_key,
+                      model_id: str,
+                      inputs: list,
+                      metadata: List[Dict] = None,
+                      prediction_only: bool = True) -> Union[List[List], Dict]:
     """Call the model's predict given the input json.
 
     Args:
@@ -574,16 +578,21 @@ def predict_for_model(api_key, model_id: str, inputs: list, metadata: List[Dict]
         model_id (str)
         inputs (list)
         metadata (List[Dict]): Metadata key/value pairs (e.g. name, url), one for each input.
+        prediction_only(bool)
 
     Raises:
         RequestException: If there was an error communicating with the server.
     """
     predict_url = f'{settings.API_URL_BASE}/models/{model_id}/predict'
-    return _predict(api_key, predict_url, inputs, metadata)
+    return _predict(api_key, predict_url, inputs, metadata, prediction_only)
 
 
 @with_api_key
-def predict_for_model_version(api_key, model_version_id: str, inputs: list, metadata: List[Dict] = None) -> List[List]:
+def predict_for_model_version(api_key,
+                              model_version_id: str,
+                              inputs: list,
+                              metadata: List[Dict] = None,
+                              prediction_only: bool = True) -> Union[List[List], Dict]:
     """Call the model version's predict given the input json.
 
     Args:
@@ -596,7 +605,7 @@ def predict_for_model_version(api_key, model_version_id: str, inputs: list, meta
         RequestException: If there was an error communicating with the server.
     """
     predict_url = f'{settings.API_URL_BASE}/model_versions/{model_version_id}/predict'
-    return _predict(api_key, predict_url, inputs, metadata)
+    return _predict(api_key, predict_url, inputs, metadata, prediction_only)
 
 
 @with_api_key
@@ -677,10 +686,14 @@ def requirement_status(api_key, requirement_id):
     return resp['data']['pynode_requirement']
 
 
-def _predict(api_key, predict_url: str, inputs: list, metadata: List[Dict] = None) -> List[List]:
+def _predict(api_key,
+             predict_url: str,
+             inputs: list,
+             metadata: List[Dict] = None,
+             prediction_only: bool = True) -> Union[List[List], Dict]:
     resp = _post_rest_query(api_key, predict_url, {'inputs': inputs, 'metadata': metadata})
     resp_json = json.loads(resp.content)
-    return resp_json['predictions']
+    return resp_json['predictions'] if prediction_only else resp_json
 
 
 def _headers(api_key):
