@@ -37,13 +37,18 @@ class ModelClassImplementationError(Error):
     pass
 
 
-class ModelInputShapeError(Error):
+class SampleDataInputShapeError(Error):
     """Raised when deploying a model whose input shape doesn't match the number of feature names given by the user."""
     pass
 
 
-class SampleDataInputShapeError(Error):
-    """Raised when deploying a model whose input shape doesn't match the number of feature names given by the user."""
+class TrussBuildError(Error):
+    """Raised when a user attempts to build a Truss and it failts"""
+    pass
+
+
+class TrussDeployError(Error):
+    """Raised when a user attempts to deploy a Truss to Baseten and it fails"""
     pass
 
 
