@@ -89,7 +89,7 @@ def deploy_truss(
     b10_truss: TrussHandle,
     model_name: str = None,
     semver_bump: Semver = Semver.MINOR.value,
-):
+) -> BasetenDeployedModel:
     """
     Given an existing baseten truss object, deploy it onto the baseten infastructure.
 
@@ -183,10 +183,19 @@ def _generate_model_deploy_logs(model_id):
     logger.info("".join(["-" for _ in range(visit_message_len)]))
 
 
-def _compress_truss(b10_truss):
-    temp_file = tempfile.NamedTemporaryFile(suffix=".tgz")
+def _create_temporary_file(b10_truss, delete=True):
+    temp_file = tempfile.NamedTemporaryFile(suffix=".tgz", delete=delete)
     with tarfile.open(temp_file.name, "w:gz") as tar:
         tar.add(b10_truss._spec.truss_dir, arcname=".")
+    return temp_file 
+
+
+def _compress_truss(b10_truss):
+    try:
+        temp_file = _create_temporary_file(b10_truss)
+    except PermissionError:
+        # Windows bug with Tempfile causes PermissionErrors 
+        temp_file = _create_temporary_file(b10_truss, delete=False)
     temp_file.file.seek(0)
     return temp_file
 
@@ -195,9 +204,9 @@ def build_and_deploy_truss(
     model: Any,
     model_name: str = None,
     version_bump=Semver.MINOR.value,
-):
+) -> BasetenDeployedModel:
     truss = build_truss(model)
-    deploy_truss(truss, model_name, version_bump)
+    return deploy_truss(truss, model_name, version_bump)
 
 
 def pull_model(model_version_id: str, directory: str = "."):
