@@ -1,6 +1,7 @@
 import configparser
 import os
 from pathlib import Path
+from urllib.parse import urlparse
 
 SKLEARN = 'sklearn'
 KERAS = 'keras'
@@ -59,4 +60,19 @@ def _api_url_base() -> str:
         return config.get('api', 'url_base')
 
 
+def _is_valid_url(url: str) -> bool:
+    try:
+        result = urlparse(url)
+        return all([result.scheme, result.netloc])
+    except ValueError:
+        return False
+
+
+def set_server_url(server_url):
+    if not _is_valid_url(server_url):
+        return False
+    set_config_value('api', 'url_base', server_url)
+    return True
+
+
 API_URL_BASE = _api_url_base()
